# Frequenz Python SDK

[![Build Status](https://github.com/frequenz-floss/frequenz-sdk-python/actions/workflows/ci.yaml/badge.svg)](https://github.com/frequenz-floss/frequenz-sdk-python/actions/workflows/ci.yaml)
[![PyPI Package](https://img.shields.io/pypi/v/frequenz-sdk)](https://pypi.org/project/frequenz-sdk/)
[![Docs](https://img.shields.io/badge/docs-latest-informational)](https://frequenz-floss.github.io/frequenz-sdk-python/)

## Introduction

A development kit to interact with the Frequenz development platform.

## Supported Platforms

The following platforms are officially supported (test):

- **Python:** 3.11, 3.12
- **Operating System:** Ubuntu Linux 20.04
- **Architectures:** amd64, arm64

## Quick Start

We assume you are on a system with Python available. If that is not the case,
please [download and install Python](https://www.python.org/downloads/) first.

To install the SDK, you probably want to create a new virtual environment first.
For example, if you use a `sh` compatible shell, you can do this:

```sh
python3 -m venv .venv
. .venv/bin/activate
```

Then, just install using `pip`:

```sh
python3 -m pip install frequenz-sdk
```

## Documentation

For more information, please visit the [documentation
website](https://frequenz-floss.github.io/frequenz-sdk-python/).

## Contributing

If you want to know how to build this project and contribute to it, please
check out the [Contributing Guide](CONTRIBUTING.md).
